@@ -1,14 +1,14 @@
 package Getopt::EX::Hashed;
 
-our $VERSION = '0.9920';
+our $VERSION = '0.9921';
 
 =head1 NAME
 
-Getopt::EX::Hashed - Hash store object automation
+Getopt::EX::Hashed - Hash store object automation for Getopt::Long
 
 =head1 VERSION
 
-Version 0.9920
+Version 0.9921
 
 =head1 SYNOPSIS
 
@@ -17,15 +17,15 @@ Version 0.9920
 
   package App::foo;
 
-  use Getopt::EX::Hashed;
-  has start    => ( spec => "=i s begin", default => 1 );
-  has end      => ( spec => "=i e" );
-  has file     => ( spec => "=s", is => 'rw', re => qr/^(?!\.)/ );
-  has score    => ( spec => '=i', min => 0, max => 100 );
-  has answer   => ( spec => '=i', must => sub { $_[1] == 42 } );
-  has mouse    => ( spec => '=s', any => [ 'Frankie', 'Benjy' ] );
-  has question => ( spec => '=s', re => qr/^(life|universe|everything)$/i);
-  no  Getopt::EX::Hashed;
+  use Getopt::EX::Hashed; {
+      has start    => ' =i  s begin ' , default => 1;
+      has end      => ' =i  e       ' ;
+      has file     => ' =s@ f       ' , is => 'rw', any => qr/^(?!\.)/;
+      has score    => ' =i          ' , min => 0, max => 100;
+      has answer   => ' =i          ' , must => sub { $_[1] == 42 };
+      has mouse    => ' =s          ' , any => [ 'Frankie', 'Benjy' ];
+      has question => ' =s          ' , any => qr/^(life|universe|everything)$/i;
+  } no Getopt::EX::Hashed;
 
   sub run {
       my $app = shift;
@@ -42,7 +42,6 @@ use Hash::Util qw(lock_keys lock_keys_plus unlock_keys);
 use Carp;
 use Data::Dumper;
 use List::Util qw(first);
-use Clone qw(clone);
 
 # store metadata in caller context
 my  %__DB__;
@@ -156,7 +155,10 @@ sub new {
 	    *{"$class\::$access"} = _accessor($is, $name)
 		unless ${"$class\::"}{$access};
 	}
-	$obj->{$name} = clone $param{default};
+	$obj->{$name} = do {
+	    local $_ = $param{default};
+	    (ref eq 'ARRAY') ? [ @$_ ] : (ref eq 'HASH') ? { %$_ } : $_;
+	};
     }
     lock_keys %$obj if $config->{LOCK_KEYS};
     $obj;
@@ -267,12 +269,20 @@ my %tester = (
     min  => sub { $_[-1] >= $_->{min} },
     max  => sub { $_[-1] <= $_->{max} },
     re   => sub { $_[-1] =~ $_->{re} },
-    must => sub { &{$_->{must}} },
-    any  => sub {
+    must => sub {
+	my $must = $_->{must};
+	for $_ (ref($must) eq 'ARRAY' ? @$must : $must) {
+	    &$_ or return 0;
+	}
+	return 1;
+    },
+    any => sub {
 	my $any = $_->{any};
 	for (ref($any) eq 'ARRAY' ? @$any : $any) {
-	    if (ref($_) eq 'Regexp') {
+	    if (ref eq 'Regexp') {
 		$_[-1] =~ $_ and return 1;
+	    } elsif (ref eq 'CODE') {
+		&$_ and return 1;
 	    } else {
 		$_[-1] eq $_ and return 1;
 	    }
@@ -324,14 +334,14 @@ __END__
 =head1 DESCRIPTION
 
 B<Getopt::EX::Hashed> is a module to automate a hash object to store
-command line option values.  Major objective of this module is
-integrating initialization and specification into single place.
-Module name shares B<Getopt::EX>, but it works independently from
-other modules included in B<Getopt::EX>, so far.
+command line option values for B<Getopt::Long> or compatible module
+including B<Getopt::EX::Long>.
 
-In the current implementation, using B<Getopt::Long>, or compatible
-module such as B<Getopt::EX::Long> is assumed.  It is configurable,
-but no other module is supported now.
+Major objective of this module is integrating initialization and
+specification into single place.
+
+Module name shares B<Getopt::EX>, but it works independently from
+other modules in B<Getopt::EX>, so far.
 
 Accessor methods are automatically generated when appropriate parameter
 is given.
@@ -348,13 +358,7 @@ If array reference is given, multiple names can be declared at once.
 
     has [ 'left', 'right' ] => ( spec => "=i" );
 
-If the number of parameter is not even, first parameter is taken as
-C<spec>.  So the above example can be written as this:
-
-    has [ 'left', 'right' ] => "=i";
-
-If the name start with plus (C<+>), given parameters are added to
-current value.
+If the name start with plus (C<+>), given parameter updates values.
 
     has '+left' => ( default => 1 );
 
@@ -362,22 +366,13 @@ Following parameters are available.
 
 =over 7
 
-=item B<is> => C<ro> | C<rw>
+=item [ B<spec> => ] I<string>
 
-To produce accessor method, C<is> parameter is necessary.  Set the
-value C<ro> for read-only, C<rw> for read-write.
+Give option specification.  C<< spec => >> label can be omitted if and
+only if it is the first parameter.
 
-If you want to make accessor for all following members, use
-C<configure> and set C<DEFAULT> parameter.
-
-    Getopt::EX::Hashed->configure( DEFAULT => [ is => 'rw' ] );
-
-=item B<spec> => I<string>
-
-Give option specification.  Option spec and alias names are separated
-by white space, and can show up in any order.
-
-Declaration
+In I<string>, option spec and alias names are separated by white
+space, and can show up in any order.  Declaration
 
     has start => ( spec => "=i s begin" );
 
@@ -407,11 +402,26 @@ string as a value.  Otherwise, it is not considered as an option.
 Additional alias names can be specified by B<alias> parameter too.
 There is no difference with ones in C<spec> parameter.
 
+=item B<is> => C<ro> | C<rw>
+
+To produce accessor method, C<is> parameter is necessary.  Set the
+value C<ro> for read-only, C<rw> for read-write.
+
+If you want to make accessor for all following members, use
+C<configure> and set C<DEFAULT> parameter.
+
+    Getopt::EX::Hashed->configure( DEFAULT => [ is => 'rw' ] );
+
 =item B<default> => I<value>
 
 Set default value.  If no default is given, the member is initialized
 as C<undef>.
 
+If the value is a reference for ARRAY or HASH, new reference with same
+member is assigned.  This means that member data is shared across
+multiple C<new> calls.  Please be careful if you call C<new> multiple
+times and alter the member data.
+
 =item B<action> => I<coderef>
 
 Parameter C<action> takes code reference which is called to process
@@ -442,7 +452,7 @@ for common rules.
 
 =over 7
 
-=item B<must> => I<coderef>
+=item B<must> => I<coderef> | [ I<codoref> ... ]
 
 Parameter C<must> takes a code reference to validate option values.
 It takes same arguments as C<action> and returns boolean.  With next
@@ -452,6 +462,12 @@ example, option B<--answer> takes only 42 as a valid value.
         spec => '=i',
         must => sub { $_[1] == 42 };
 
+If multiple code reference is given, all code have to return true.
+
+    has answer =>
+        spec => '=i',
+        must =>[ sub { $_[1] >= 42 }, sub { $_[1] <= 42 } ];
+
 =item B<min> => I<number>
 
 =item B<max> => I<number>
@@ -460,7 +476,7 @@ Set the minimum and maximum limit for the argument.
 
 =item B<any> => I<arrayref> | qr/I<regex>/
 
-Set the valid string parameter list.  Each item is string or regex
+Set the valid string parameter list.  Each item is a string or a regex
 reference.  The argument is valid when it is same as, or match to any
 item of the given list.  If the value is not a arrayref, it is taken
 as a single item list (regexpref usually).
